@@ -7,7 +7,6 @@ The available commands are:
   setup  Setup configuration
   show   Show current configuration
 """
-# :copyright: (c) 2013, SoftLayer Technologies, Inc. All rights reserved.
 # :license: MIT, see LICENSE for more details.
 
 import os.path
@@ -16,7 +15,7 @@ from SoftLayer import (
     Client, SoftLayerAPIError, API_PUBLIC_ENDPOINT, API_PRIVATE_ENDPOINT)
 from SoftLayer.CLI import (
     CLIRunnable, CLIAbort, KeyValueTable, confirm, format_output)
-import ConfigParser
+from SoftLayer.utils import configparser
 
 
 def get_settings_from_client(client):
@@ -40,17 +39,20 @@ def get_settings_from_client(client):
 
 
 def config_table(settings):
-    t = KeyValueTable(['Name', 'Value'])
-    t.align['Name'] = 'r'
-    t.align['Value'] = 'l'
-    t.add_row(['Username', settings['username'] or 'not set'])
-    t.add_row(['API Key', settings['api_key'] or 'not set'])
-    t.add_row(['Endpoint URL', settings['endpoint_url'] or 'not set'])
-    t.add_row(['Timeout', settings['timeout'] or 'not set'])
-    return t
+    """ Returns a config table """
+    table = KeyValueTable(['Name', 'Value'])
+    table.align['Name'] = 'r'
+    table.align['Value'] = 'l'
+    table.add_row(['Username', settings['username'] or 'not set'])
+    table.add_row(['API Key', settings['api_key'] or 'not set'])
+    table.add_row(['Endpoint URL', settings['endpoint_url'] or 'not set'])
+    table.add_row(['Timeout', settings['timeout'] or 'not set'])
+    return table
 
 
 def get_api_key(username, secret, endpoint_url=None):
+    """ Tries API-Key and password auth to get (and potentially generate) an
+        API key. """
     # Try to use a client with username/api key
     try:
         client = Client(
@@ -61,8 +63,8 @@ def get_api_key(username, secret, endpoint_url=None):
 
         client['Account'].getCurrentUser()
         return secret
-    except SoftLayerAPIError as e:
-        if 'invalid api token' not in e.faultString.lower():
+    except SoftLayerAPIError as ex:
+        if 'invalid api token' not in ex.faultString.lower():
             raise
 
     # Try to use a client with username/password
@@ -145,23 +147,25 @@ Setup configuration
 
         # Persist the config file. Read the target config file in before
         # setting the values to avoid clobbering settings
-        config = ConfigParser.RawConfigParser()
+        config = configparser.RawConfigParser()
         config.read(config_path)
         try:
             config.add_section('softlayer')
-        except ConfigParser.DuplicateSectionError:
+        except configparser.DuplicateSectionError:
             pass
 
         config.set('softlayer', 'username', settings['username'])
         config.set('softlayer', 'api_key', settings['api_key'])
         config.set('softlayer', 'endpoint_url', settings['endpoint_url'])
 
-        f = os.fdopen(os.open(
-            config_path, (os.O_WRONLY | os.O_CREAT), 0600), 'w')
+        config_file = os.fdopen(os.open(config_path,
+                                        (os.O_WRONLY | os.O_CREAT),
+                                        0o600),
+                                'w')
         try:
-            config.write(f)
+            config.write(config_file)
         finally:
-            f.close()
+            config_file.close()
 
         return "Configuration Updated Successfully"
 
